/* This file is part of the Connector Framework
 * Copyright (C) 2008-2013 Index Data
 * See the file LICENSE for details.
 */
/**
 * \file cf_logger.h
 * \brief Logger interface
 */


#ifndef cf_logger_h
#define cf_logger_h 1

#include <yaz/log.h>

class CF_Logger {
public:
    static const char *logstr(int level);
    CF_Logger(){};
    virtual ~CF_Logger(){};
    virtual void printf(const char *module, int level, const char *fmt, ...) = 0;
};

#endif
/*
 * Local variables:
 * c-basic-offset: 4
 * c-file-style: "Stroustrup"
 * indent-tabs-mode: nil
 * End:
 * vim: shiftwidth=4 tabstop=8 expandtab
 */

